pub fn validate_detections(
detections: Vec<Detection>,
netelements: &[Netelement],
) -> Result<ValidationOutcome, DetectionError>Expand description
Validate a set of detections against the available netelements.
pub fn validate_detections(
detections: Vec<Detection>,
netelements: &[Netelement],
) -> Result<ValidationOutcome, DetectionError>Validate a set of detections against the available netelements.